=======
History
=======

0.2.3 (2021-11-24)
------------------

* Update Landfill


0.2.1 (2021-10-02)
------------------

* New models: Gasification & Syngas combustion (GC), Refuse-Derived Fuel (RDF), Home composting (HC) 


0.1.9 (2021-05-10)
------------------

* Life cycle cost, input data for TS, References 


0.1.0 (2020-05-06)
------------------

* First release on PyPI. Data for the Life-cycle process models include: LF, WTE, Composting, AD, SS_MRF, reprocessing and Collection.
